@@ -23,10 +23,14 @@ class DataRegex(Enum):
     """regular expression patterns for different kinds of data and their properties"""
 
     DATA = f"^(?P<label>.+?)_(?P<c_date>{RegexParts.DATE.value})_(?P<c_time>{RegexParts.TIME.value})$"
-    RAW_DATA = f"^(?P<modality>.+?)_(?P<subject_id>.+?)_(?P<c_date>{RegexParts.DATE.value})_(?P<c_time>" \
-               f"{RegexParts.TIME.value})$"
-    DERIVED_DATA = f"^(?P<input>.+?_{RegexParts.DATE.value}_{RegexParts.TIME.value})_(?P<process_name>.+?)_(?P<c_date>"\
-                   f"{RegexParts.DATE.value})_(?P<c_time>{RegexParts.TIME.value})"
+    RAW_DATA = (
+        f"^(?P<modality>.+?)_(?P<subject_id>.+?)_(?P<c_date>{RegexParts.DATE.value})_(?P<c_time>"
+        f"{RegexParts.TIME.value})$"
+    )
+    DERIVED_DATA = (
+        f"^(?P<input>.+?_{RegexParts.DATE.value}_{RegexParts.TIME.value})_(?P<process_name>.+?)_(?P<c_date>"
+        f"{RegexParts.DATE.value})_(?P<c_time>{RegexParts.TIME.value})"
+    )
     NO_UNDERSCORES = "^[^_]+$"
 
 
@@ -121,13 +125,19 @@ class DataDescription(AindCoreModel):
         title="Institution",
     )
     funding_source: List[Funding] = Field(
-        ..., title="Funding source", description="Funding sources. If internal label as Institution.",
+        ...,
+        title="Funding source",
+        description="Funding sources. If internal label as Institution.",
     )
     data_level: DataLevel = Field(
-        ..., description="level of processing that data has undergone", title="Data Level",
+        ...,
+        description="level of processing that data has undergone",
+        title="Data Level",
     )
     group: Optional[Group] = Field(
-        None, description="A short name for the group of individuals that collected this data", title="Group",
+        None,
+        description="A short name for the group of individuals that collected this data",
+        title="Group",
     )
     project_name: Optional[str] = Field(
         None,
@@ -135,20 +145,26 @@ class DataDescription(AindCoreModel):
         title="Project Name",
     )
     project_id: Optional[str] = Field(
-        None, description="A database or other identifier for a project", title="Project ID",
+        None,
+        description="A database or other identifier for a project",
+        title="Project ID",
     )
     restrictions: Optional[str] = Field(
-        None, description="Detail any restrictions on publishing or sharing these data", title="Restrictions",
+        None,
+        description="Detail any restrictions on publishing or sharing these data",
+        title="Restrictions",
     )
     modality: str = Field(
         ...,
         regex=DataRegex.NO_UNDERSCORES.value,
         description="A short name for the specific manner, characteristic, pattern of application, or the employment of"
-                    " any technology or formal procedure to generate data for a study",
+        " any technology or formal procedure to generate data for a study",
         title="Modality",
     )
     subject_id: str = Field(
-        ..., regex=DataRegex.NO_UNDERSCORES.value, description="Unique identifier for the subject of data acquisition",
+        ...,
+        regex=DataRegex.NO_UNDERSCORES.value,
+        description="Unique identifier for the subject of data acquisition",
     )
 
     def __init__(self, label=None, **kwargs):
@@ -157,7 +173,11 @@ class DataDescription(AindCoreModel):
         super().__init__(**kwargs)
 
         if label is not None:
-            self.name = build_data_name(label, creation_date=self.creation_date, creation_time=self.creation_time,)
+            self.name = build_data_name(
+                label,
+                creation_date=self.creation_date,
+                creation_time=self.creation_time,
+            )
 
     @classmethod
     def parse_name(cls, name):
@@ -169,7 +189,11 @@ class DataDescription(AindCoreModel):
 
         creation_date, creation_time = datetime_from_name_string(m.group("c_date"), m.group("c_time"))
 
-        return dict(label=m.group("label"), creation_date=creation_date, creation_time=creation_time,)
+        return dict(
+            label=m.group("label"),
+            creation_date=creation_date,
+            creation_time=creation_time,
+        )
 
     @classmethod
     def from_name(cls, name, **kwargs):
@@ -245,7 +269,10 @@ class RawDataDescription(DataDescription):
     """A logical collection of data files as acquired from a rig or instrument"""
 
     data_level: DataLevel = Field(
-        DataLevel.RAW_DATA, description="level of processing that data has undergone", title="Data Level", const=True,
+        DataLevel.RAW_DATA,
+        description="level of processing that data has undergone",
+        title="Data Level",
+        const=True,
     )
 
     def __init__(self, **kwargs):
